@@ -55,6 +55,8 @@ Backupsets:
     
     add_archiveset(archiveset_name)   -- adds a new archiveset to the agent of the specified client
 
+    add_v1_sharepoint_client()      -- Adds a new Office 365 V1 Share Point Pseudo Client to the Commcell.
+
     add_salesforce_backupset()      -- adds a new salesforce backupset
 
     get(backupset_name)             -- returns the Backupset class object
@@ -111,11 +113,16 @@ Backupset:
 
     find()                          -- find content in the backupset
 
+    list_media()                    -- List media required to browse and restore backed up data from the backupset
+
     refresh()                       -- refresh the properties of the backupset
 
     delete_data()                   -- deletes items from the backupset and makes then unavailable
     to browse and restore
 
+    backed_up_files_count()         -- Returns the count of the total number of files present in the backed up data
+                                       of all the subclients of the given backupset.
+
 Backupset instance Attributes
 -----------------------------
 
@@ -182,7 +189,8 @@ class Backupsets(object):
         self._update_response_ = self._commcell_object._update_response_
 
         self._BACKUPSETS = self._services['GET_ALL_BACKUPSETS'] % (self._client_object.client_id)
-
+        if self._agent_object:
+            self._BACKUPSETS += '&applicationId=' + self._agent_object.agent_id
         from .backupsets.fsbackupset import FSBackupset
         from .backupsets.nasbackupset import NASBackupset
         from .backupsets.hanabackupset import HANABackupset
@@ -690,6 +698,116 @@ request_json['backupSetInfo'].update({
         else:
             raise SDKException('Response', '101', self._update_response_(response.text))
 
+    def add_v1_sharepoint_client(
+            self,
+            backupset_name,
+            server_plan,
+            client_name,
+            **kwargs):
+        """
+        for sharepoint v1 client creation is a backupset
+        Adds a new Office 365 V1 Share Point Pseudo Client to the Commcell.
+
+                Args:
+                    backupset_name                 (str)   --  name of the new Sharepoint Pseudo Client
+
+                    server_plan                 (str)   --  server_plan to associate with the client
+
+                    client_name                 (str) -- the access node for which Pseudo Client will be created
+
+
+                Kwargs :
+
+                    tenant_url                  (str)   --  url of sharepoint tenant
+
+                    azure_username              (str)   --  username of azure app
+
+                    azure_secret                (str)   --  secret key of azure app
+
+                    user_username        (str)   --  username of Sharepoint admin
+
+                    user_password           (str)  -- password of Sharepoint admin
+
+                    azure_app_id            (str)       --  azure app id for sharepoint online
+
+                    azure_app_key_id        (str)       --  app key for sharepoint online
+
+                    azure_directory_id    (str)   --  azure directory id for sharepoint online
+
+
+                Returns:
+                    object  -   instance of the Client class for this new client
+
+                Raises:
+                    SDKException:
+                        if client with given name already exists
+
+                        if index_server is not found
+
+                        if server_plan is not found
+
+                        if failed to add the client
+
+                        if response is empty
+
+                        if response is not success
+
+        """
+        if self.has_backupset(backupset_name):
+            raise SDKException(
+                'Backupset', '102', 'Backupset "{0}" already exists.'.format(backupset_name))
+        if self._commcell_object.plans.has_plan(server_plan):
+            server_plan_object = self._commcell_object.plans.get(server_plan)
+            server_plan_dict = {
+                "planId": int(server_plan_object.plan_id)
+            }
+        else:
+            raise SDKException('Backupset', '102')
+        backup_set = {
+            "_type_": 6,
+            "applicationId": 78,
+            "backupsetName": backupset_name,
+            "clientId": int(self._client_object.client_id)
+        }
+        request_json = {
+            "backupSetInfo": {
+                "planEntity": server_plan_dict,
+                "backupSetEntity": backup_set,
+                "sharepointBackupSet": {
+                    "sharepointBackupSetType": 4
+                }
+            }
+        }
+        tenant_url = kwargs.get('tenant_url')
+        user_username = kwargs.get('user_username')
+        is_modern_auth_enabled = kwargs.get('is_modern_auth_enabled',False)
+        azure_secret = b64encode(kwargs.get('azure_secret').encode()).decode()
+        azure_app_key_id = b64encode(kwargs.get('azure_app_key_id').encode()).decode()
+        user_password = b64encode(kwargs.get('user_password').encode()).decode()
+        request_json["backupSetInfo"]["sharepointBackupSet"][
+            "spOffice365BackupSetProp"] = {
+            "azureUserAccount": kwargs.get('azure_username'),
+            "azureAccountKey": azure_secret,
+            "tenantUrlItem": tenant_url,
+            "isModernAuthEnabled": is_modern_auth_enabled,
+            "office365Credentials": {
+                "userName": user_username,
+                "password": user_password
+            },
+        }
+        if is_modern_auth_enabled:
+            request_json["backupSetInfo"]["sharepointBackupSet"][
+                "spOffice365BackupSetProp"]["azureAppList"] = {
+                "azureApps": [
+                    {
+                        "azureAppId": kwargs.get('azure_app_id'),
+                        "azureAppKeyValue": azure_app_key_id,
+                        "azureDirectoryId": kwargs.get('azure_directory_id')
+                    }
+                ]
+            }
+
+        self._process_add_response(backupset_name, request_json)
 
     def add_salesforce_backupset(
             self,
@@ -984,7 +1102,8 @@ class Backupset(object):
         self._is_on_demand_backupset = False
         self._properties = None
         self._backupset_association = {}
-        self._plan = None
+        self._plan_name = None
+        self._plan_obj = None
 
         self.subclients = None
         self.schedules = None
@@ -1009,11 +1128,13 @@ class Backupset(object):
             'include_meta_data':False,
             'include_hidden': False,
             'include_running_jobs': False,
+            'compute_folder_size': False,
             'vs_volume_browse': False,
             'browse_view_name': 'VOLUMEVIEW',
 
             '_subclient_id': 0,
-            '_raw_response': False
+            '_raw_response': False,
+            '_custom_queries': False
         }
 
     def __getattr__(self, attribute):
@@ -1076,11 +1197,9 @@ class Backupset(object):
                     self._description = self._properties["commonBackupSet"]["userDescription"]
 
                 if "planName" in self._properties["planEntity"]:
-                    self._plan = self._commcell_object.plans.get(
-                        self._properties["planEntity"]["planName"]
-                    )
+                    self._plan_name = self._properties["planEntity"]["planName"]
                 else:
-                    self._plan = None
+                    self._plan_name = None
             else:
                 raise SDKException('Response', '102')
         else:
@@ -1288,6 +1407,7 @@ class Backupset(object):
             'browse': 0,
             'find': 1,
             'all_versions': 2,
+            'list_media': 3,
             'delete_data': 7
         }
 
@@ -1301,7 +1421,7 @@ class Backupset(object):
         browse_mode = {
             'virtual server': 4,
             'cloud apps': 3,
-            'azure ad' : 3						  
+            'azure ad': 3
         }
 
         mode = 2
@@ -1403,11 +1523,20 @@ class Backupset(object):
         if options['include_running_jobs']:
             request_json['options']['includeRunningJobs'] = True
 
+        if options['compute_folder_size']:
+            request_json['options']['computeFolderSizeForFilteredBrowse'] = True
+
         if options['vs_volume_browse']:
             request_json['mode']['mode'] = 3
             request_json['options']['vsVolumeBrowse'] = True
             request_json['advOptions']['browseViewName'] = options['browse_view_name']
 
+        if options['operation'] == 'list_media':
+            request_json['options']['doPrediction'] = True
+
+        if options['_custom_queries']:
+            request_json['queries'] = options['_custom_queries']
+
         return request_json
 
     def _process_browse_all_versions_response(self, result_set):
@@ -1507,6 +1636,9 @@ class Backupset(object):
             ),
             "delete_data": (
                 '113', 'Failed to perform delete data operation for given content\nError: "{0}"'
+            ),
+            "list_media": (
+                '113', 'Failed to perform list media operation for given content\nError: "{0}"'
             )
         }
 
@@ -1711,7 +1843,13 @@ class Backupset(object):
     @property
     def plan(self):
         """Treats the backupset plan as a property of the Backupset class."""
-        return self._plan
+        if self._plan_obj is not None:
+            return self._plan_obj
+        elif self._plan_name is not None:
+            self._plan_obj = self._commcell_object.plans.get(self._plan_name)
+            return self._plan_obj
+        else:
+            return None
 
     @property
     def guid(self):
@@ -1785,7 +1923,7 @@ class Backupset(object):
             Args:
                 value   (object)    --  the Plan object which is to be associated
                                         with the backupset
-                
+
                 value   (str)       --  name of the plan which is to be associated
                                         with the backupset
 
@@ -1802,13 +1940,11 @@ class Backupset(object):
         """
         from .plan import Plan
         if isinstance(value, Plan):
-            plan_obj = value
+            self._plan_obj = value
         elif isinstance(value, basestring):
-            plan_obj = self._commcell_object.plans.get(value)
+            self._plan_obj = self._commcell_object.plans.get(value)
         elif value is None:
-            plan_obj = {
-                'planName': None
-            }
+            self._plan_obj = None
         else:
             raise SDKException('Backupset', '102', 'Input value is not of supported type')
 
@@ -1818,15 +1954,15 @@ class Backupset(object):
             'appId': int(self._agent_object.agent_id),
             'backupsetId': int(self.backupset_id)
         }
-        if value is not None and plan_obj.plan_name in plans_obj.get_eligible_plans(entity_dict):
+        if value is not None and self._plan_obj.plan_name in plans_obj.get_eligible_plans(entity_dict):
             request_json = {
                 'backupsetProperties': {
                     'planEntity': {
-                        'planSubtype': int(plan_obj.subtype),
+                        'planSubtype': int(self._plan_obj.subtype),
                         '_type_': 158,
-                        'planType': int(plan_obj.plan_type),
-                        'planName': plan_obj.plan_name,
-                        'planId': int(plan_obj.plan_id)
+                        'planType': int(self._plan_obj.plan_type),
+                        'planName': self._plan_obj.plan_name,
+                        'planId': int(self._plan_obj.plan_id)
                     }
                 }
             }
@@ -1929,7 +2065,7 @@ class Backupset(object):
                     Example:
 
                         browse({
-                            'path': 'c:\\\\hello',
+                            'path': 'c:\\hello',
 
                             'show_deleted': True,
 
@@ -2033,7 +2169,8 @@ class Backupset(object):
         else:
             options = kwargs
 
-        options['operation'] = 'find'
+        if 'operation' not in options:
+            options['operation'] = 'find'
 
         if 'path' not in options:
             options['path'] = '\\**\\*'
@@ -2054,6 +2191,27 @@ class Backupset(object):
             options['filters'].append(('FileSize', options['file_size_et'], 'EQUALSBLAH'))
 
         return self._do_browse(options)
+    
+    def create_subclient(self, subclient, storagepolicyname, description):
+
+            """"
+            This is to create new subclient
+            
+            Args: 
+                subclientname (str) - subclient name to be created
+                storagepolicyname  (str) - name of the storage policy associate to subclient
+                description (str) - Description for subclient which is to be created
+            Raise:
+                  Exception:
+                    If fail to create subclient
+    
+            """
+            try:
+                self.subclients.add(subclient, storagepolicyname,description)
+            except Exception as err:
+                self.log.exception(
+                    "Exception while adding contents to subclient" + str(err))
+                raise err
 
     def delete_data(self, paths):
         """Deletes items for the backupset in the Index and makes them unavailable for
@@ -2083,9 +2241,89 @@ class Backupset(object):
         if files:
             raise SDKException('Backupset', '102', 'Delete data operation gave unexpected results')
 
+    def list_media(self, *args, **kwargs):
+        """List media required to browse and restore backed up data from the backupset
+
+            Args:
+                Dictionary of options:
+                    Example:
+
+                        list_media({
+                            'path': 'c:\\hello',
+                            'show_deleted': True,
+                            'from_time': '2020-04-20 12:00:00',
+                            'to_time': '2021-04-19 12:00:00'
+                        })
+
+            Kwargs:
+                Keyword argument of options:
+                    Example:
+
+                        list_media(
+                            path='c:\\hello',
+                            show_deleted=True,
+                            from_time='2020-04-20 12:00:00',
+                            to_time='2021-04-19 12:00:00'
+                        )
+
+            Note:
+                Refer `_default_browse_options` for all the supported options.
+
+            Returns:
+                (List, Dict) -
+                    List - List of all the media required for the given options
+
+                    Dict - Total size of the media
+
+            Raises:
+                SDKException:
+                    if failed to list media for content
+
+                    if response is not success
+
+        """
+
+        if args and isinstance(args[0], dict):
+            options = args[0]
+        else:
+            options = kwargs
+
+        options['operation'] = 'list_media'
+        options['_raw_response'] = True
+
+        _, response = self._do_browse(options)
+
+        if response and 'browseResponses' in response:
+            responses = response['browseResponses']
+            list_media_response = responses[0]
+
+            prediction_data = list_media_response.get('predictionData', [])
+            browse_result = list_media_response.get('browseResult', {})
+
+            return prediction_data, browse_result
+        else:
+            raise SDKException('Backupset', '102', 'List media operation gave unexpected results')
+
     def refresh(self):
         """Refresh the properties of the Backupset."""
         self._get_backupset_properties()
 
         self.subclients = Subclients(self)
         self.schedules = Schedules(self)
+
+    def backed_up_files_count(self):
+        """Returns the count of the total number of files present in the backed up data
+         of all the subclients of the given backupset.
+         """
+        options_dic = {"operation": "find", "opType": 1, "path": "\**\*",
+               "_custom_queries": [{"type": "AGGREGATE", "queryId": "2",
+                                    "aggrParam": {"aggrType": "COUNT"}, "whereClause": [{
+                       "criteria": {
+                           "field": "Flags",
+                           "dataOperator": "IN",
+                           "values": ["file"]
+                       }
+                   }]}], "_raw_response": True}
+
+        browse_response = self._do_browse(options_dic)
+        return browse_response[1]['browseResponses'][0]['browseResult']['aggrResultSet'][0]['count']
