@@ -130,14 +130,14 @@ class ContentAnalyzers(object):
                     {
                         "contentAnalyzerList": [
                                 {
-                                    "caUrl": "http://V11LotusClient.idx.commvault.com:22005",
-                                     "cloudName": "V11lotusClientCloud",
-                                     "cloudId": 1010
+                                    "caUrl": "",
+                                     "cloudName": "",
+                                     "cloudId": 0
                                 },
                                 {
-                                      "caUrl": "http://imsolrscale1.sna.commvault.com:22001",
-                                      "cloudName": "Imsolrcloud",
-                                      "cloudId": 1026
+                                      "caUrl": "",
+                                      "cloudName": "",
+                                      "cloudId": 0
                                 }
                         ]
                     }
