@@ -84,7 +84,8 @@ from __future__ import unicode_literals
 EXCEPTION_DICT = {
     'Response': {
         '101': 'Response was not success',
-        '102': 'Response received is empty'
+        '102': 'Response received is empty',
+        '500': 'Unable to perform the requested method'
     },
     'Commcell': {
         '101': 'Commcell is not reachable. Please check the commcell name and services again',
@@ -92,7 +93,8 @@ EXCEPTION_DICT = {
         '103': 'Failed to get the CommServ details',
         '104': 'Failed to send an email to specified user',
         '105': 'Failed to run the Data Aging job',
-        '106': 'Failed to get the SAML token'
+        '106': 'Failed to get the SAML token',
+        '107': 'Data type of the input(s) is not valid'
     },
     'CVPySDK': {
         '101': 'Failed to Login with the credentials provided',
@@ -140,7 +142,8 @@ EXCEPTION_DICT = {
         '105': 'Could not fetch instance property',
         '106': 'Invalid policy name under given instance. Validate the policy name',
         '107': 'Unsupported auto discovery mode provided.'
-               'Valid values are REGEX and GROUP'
+               'Valid values are REGEX and GROUP',
+        '108': 'Invalid FREL client'
     },
     'Subclient': {
         '101': 'Data type of the input(s) is not valid',
@@ -195,7 +198,8 @@ EXCEPTION_DICT = {
         '102': 'Data type of the input(s) is not valid',
         '103': 'Invalid operation type passed to Schedules class',
         '104': 'Provided Option cannot be updated',
-        '105': 'Could not find the provided schedule name/id'
+        '105': 'Could not find the provided schedule name/id',
+        '106': ''
     },
     'ClientGroup': {
         '101': 'Data type of the input(s) is not valid',
@@ -239,7 +243,32 @@ EXCEPTION_DICT = {
         '103': 'Failed to get entity regex details from commcell',
         '104': 'Unable to create regex entity in the commcell',
         '105': 'Unable to delete regex entity in the commcell',
-        '106': 'Unable to modify regex entity in the commcell'
+        '106': 'Unable to modify regex entity in the commcell',
+        '107': 'Failed to get entity container details from commcell'
+    },
+    'Classifier': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': '',
+        '103': 'Failed to get classifier details from commcell',
+        '104': 'Unable to create classifier in the commcell',
+        '105': 'Unable to delete classifier in the commcell',
+        '106': 'Unable to modify classifier in the commcell',
+        '107': 'Training model data zip file not exists in given path',
+        '108': 'Model Data Training failed on this classifier',
+        '109': 'Cancel Training failed on this classifier'
+    },
+    'Tags': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': '',
+        '103': 'Failed to get TagSet details from commcell',
+        '104': 'Unable to create TagSet in the commcell',
+        '105': 'Unable to modify TagSet in the commcell',
+        '106': 'Unable to find given tag name in this tagset',
+        '107': 'Unable to do TagSet security association in the commcell'
+    },
+    'EntityManager': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': ''
     },
     'GlobalFilter': {
         '101': 'Data type of the input(s) is not valid',
@@ -247,7 +276,32 @@ EXCEPTION_DICT = {
     },
     'Plan': {
         '101': 'Data type of the input(s) is not valid',
-        '102': ''
+        '102': '',
+        '103': 'Content Analyzer input is missing',
+        '104': 'Please provide either entity list or classifier list in input',
+        '105': 'Failed to share plan with user or group'
+    },
+    'Inventory': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': '',
+        '103': 'Failed to fetch inventories details from commcell',
+        '104': 'Failed to fetch inventory properties from commcell',
+        '105': 'Failed to create an Inventory',
+        '106': 'Unable to find inventory in commcell',
+        '107': 'Failed to Delete an Inventory',
+        '108': 'Failed to add asset to Inventory',
+        '109': 'Unable to find asset in the Inventory',
+        '110': 'Failed to delete asset from Inventory',
+        '111': 'Failed to share Inventory'
+
+
+    },
+    'EdiscoveryClients': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': '',
+        '103': 'Failed to start crawl job',
+        '104': 'Failed to get job history',
+        '105': 'Failed to get job status',
     },
     'Salesforce': {
         '101': 'Neither Sync Database enabled nor user provided database details for restore',
@@ -316,7 +370,8 @@ EXCEPTION_DICT = {
         '111': ('Plan is not associated with the organization. '
                 'Add plan to the Organization, and then set it as the default'),
         '112': 'Failed to activate organization',
-        '113': 'Failed to deactivate organization'
+        '113': 'Failed to deactivate organization',
+        '114': 'Input is not provided in expected manner'
     },
     'StoragePool': {
         '101': 'Data type of the input(s) is not valid',
@@ -327,7 +382,15 @@ EXCEPTION_DICT = {
         '101': 'Data type of the input(s) is not valid',
         '102': ''
     },
-
+    'BLRPairs': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': 'BLR Pair not found',
+        '103': 'RPStore not found'
+    },
+    'ReplicationGroup': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': ''
+    },
     'FailoverGroup': {
         '101': 'Data type of the input(s) is not valid',
         '102': ''
@@ -396,7 +459,10 @@ EXCEPTION_DICT = {
         '101': 'Failed to register commcell',
         '102': '',
         '103': 'Failed to unregister commcell',
-        '104': 'Datatype of the input is not valid'
+        '104': 'Datatype of the input is not valid',
+        '105': 'Failed to reach remote commcell.',
+        '106': 'Failed to authenticate remote commcell. Invalid user name and password.',
+        '107': 'Insufficient permissions'
     },
     'LiveSync': {
         '101': 'Data type of the input(s) is not valid',
@@ -417,7 +483,9 @@ EXCEPTION_DICT = {
         '105': 'Unsupported backup level specified. Please check',
         '106': 'Storage policy is not associated with subclient. Please associate',
         '107': 'Backup is not enabled for client/subclient',
-        '108': 'Client name not specified for solr cloud restore'
+        '108': 'Client name not specified for solr cloud restore',
+        '109': 'Provide the Index Server Node name for browse to work',
+        '110': 'Multiple roles found, Unix Index Server Browse works for only 1 role at a time.'
     },
     'HACClusters': {
         '101': 'Data type of the input(s) is not valid',
@@ -428,6 +496,16 @@ EXCEPTION_DICT = {
         '101': 'Data type of the input(s) is not valid',
         '102': 'Index pool not found',
         '103': 'Index pool node not found',
+    },
+    'Metallic': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': ''
+    },
+    'KeyManagementServer': {
+        '101': 'Data type of the input(s) is not valid',
+        '102': 'Key Management Server not found',
+        '103': 'Key Management Server type is not valid',
+        '104': 'Key Management Server type not found',
     }
 }
 
@@ -449,6 +527,8 @@ class SDKException(Exception):
                 object  -   instance of the SDKException class of type Exception
 
         """
+        exception_id = str(exception_id)
+
         self.exception_module = exception_module
         self.exception_id = exception_id
         self.exception_message = EXCEPTION_DICT[exception_module][exception_id]
