@@ -69,6 +69,8 @@ class CloudAppsInstance(Instance):
         from .cloudapps.amazon_instance import AmazonDocumentDBInstance
         from .cloudapps.amazon_instance import AmazonRDSInstance
         from .cloudapps.amazon_instance import AmazonDynamoDBInstance
+        from .cloudapps.dynamics365_instance import MSDynamics365Instance
+        from .cloudapps.teams_instance import TeamsInstance
         instance_type = {
             1: GoogleInstance,
             2: GoogleInstance,
@@ -86,7 +88,9 @@ class CloudAppsInstance(Instance):
             27: AmazonDocumentDBInstance, # Amazon Document DB
             25: CloudStorageInstance,   #AliBaba
             24: CloudStorageInstance,   #IBM
-            22: AmazonDynamoDBInstance  # Amazon DynamoDB
+            22: AmazonDynamoDBInstance, # Amazon DynamoDB
+            35: MSDynamics365Instance,   #  MS Dynamics 365 Instance
+            36: TeamsInstance, # Office 365 Teams
         }
 
         commcell_object = agent_object._commcell_object
