@@ -276,11 +276,17 @@ class OracleInstance(DatabaseInstance):
 
             })
 
-    def _get_live_sync_oracleopt_json(self):
+    def _get_live_sync_oracleopt_json(self, **kwargs):
         """
                Constructs JSON with oracle agent specific options
                for configuring live sync
 
+               Args:
+                    **kwargs    (dict)  -- dict of keyword arguments as follows:
+
+                                           redirect_path   (str)- Path on destination client
+                                                        to redirect tablespaces and datafiles
+
         """
 
         self._oracle_options = {"renamePathForAllTablespaces":"",
@@ -310,10 +316,14 @@ class OracleInstance(DatabaseInstance):
                                     "restoreInStandby":False
                                 }
                                 }
+        if kwargs.get('redirect_path', None) is not None:
+            self._oracle_options.update({"renamePathForAllTablespaces": kwargs.get('redirect_path'),
+                                         "redirectAllItemsSelected": True,
+                                         "redirectItemsPresent": True
+                                         })
 
-
-    def _live_sync_restore_json(self, dest_client, dest_instance, baseline_jobid,
-                                baseline_ref_time, schedule_name, source_backupset_id):
+    def _live_sync_restore_json(self, dest_client, dest_instance, baseline_jobid, baseline_ref_time,
+                                schedule_name, source_backupset_id, **kwargs):
         """
                Constructs oracle live sync restore JSON by combining common
                and agent specific options
@@ -334,6 +344,11 @@ class OracleInstance(DatabaseInstance):
                                                         of source oracle instance for which
                                                         live sync needs to be configured
 
+                       **kwargs    (dict)  -- dict of keyword arguments as follows:
+
+                                           redirect_path   (str)- Path on destination client
+                                                        to redirect tablespaces and datafiles
+
                     Returns:
                         (str)  --   The live sync restore JSON that is constructed
                                     using oracle and common options
@@ -356,7 +371,7 @@ class OracleInstance(DatabaseInstance):
         else:
             restore_option.update(restore_json)
 
-        self._get_live_sync_oracleopt_json()
+        self._get_live_sync_oracleopt_json(**kwargs)
         restore_json['taskInfo']['associations'][0]['subclientId'] = -1
         restore_json['taskInfo']['associations'][0]['backupsetId'] = source_backupset_id
         restore_json['taskInfo']['associations'][0]['subclientName'] = ""
@@ -379,8 +394,8 @@ class OracleInstance(DatabaseInstance):
             "restoreOptions"]["oracleOpt"] = self._oracle_options
         return restore_json
 
-
-    def create_live_sync_schedule(self, dest_client, dest_instance, schedule_name):
+    def create_live_sync_schedule(self, dest_client, dest_instance, schedule_name,
+                                  **kwargs):
         """
                Runs full backup on source oracle instance and
                Creates live sync schdule for the given destination oracle instance
@@ -392,6 +407,11 @@ class OracleInstance(DatabaseInstance):
 
                        schedule_name    (str)   --  The name of the live sync schedule to be created
 
+                       **kwargs    (dict)  -- dict of keyword arguments as follows:
+
+                                            redirect_path   (str) --  Path on destination client
+                                                            to redirect tablespaces and datafiles
+
                    Returns:
                         (object)  --   The job object of the baseline backup that will be replicated
 
@@ -404,7 +424,8 @@ class OracleInstance(DatabaseInstance):
         baseline_ref_time = baseline_job_object.summary['jobStartTime']
         baseline_jobid = int(baseline_job_object.job_id)
         request_json = self._live_sync_restore_json(dest_client, dest_instance, baseline_jobid,
-                                                    baseline_ref_time, schedule_name, source_backupset_id)
+                                                    baseline_ref_time, schedule_name,
+                                                    source_backupset_id, **kwargs)
         flag, response = self._cvpysdk_object.make_request('POST', self._LIVE_SYNC, request_json)
         if flag:
             if response.json():
@@ -422,7 +443,6 @@ class OracleInstance(DatabaseInstance):
         else:
             raise SDKException('Instance', '101', self._update_response_(response.text))
 
-
     def configure_data_masking_policy(self, policy_name, table_list_of_dict):
         """Configures data masking policy with given parameters
         Args:
@@ -1093,7 +1113,7 @@ class OracleInstance(DatabaseInstance):
         """
         if not isinstance(value,dict):
             raise SDKException('Instance','101')
-            
+
         self._oracle_restore_json = {
             "validate": False,
             "noCatalog": False,
@@ -1120,7 +1140,59 @@ class OracleInstance(DatabaseInstance):
             ],
             "restoreTime": {}
         }
-        
+
+        if value.get("restore_oracle_options_type") == "restore_archivelogs_norecover":
+            self._oracle_restore_json = {
+                "resetLogs": 0,
+                "backupValidationOnly": False,
+                "threadId": 1,
+                "deviceType": 0,
+                "restoreFailover": True,
+                "resetDatabase": False,
+                "noCatalog": True,
+                "ctrlRestoreFrom": False,
+                "controlFilePath": "",
+                "specifyControlFileTime": False,
+                "restoreDataTag": False,
+                "useEndLSN": False,
+                "useStartLSN": False,
+                "restoreTablespace": False,
+                "archiveLogBy": 1,
+                "ctrlFileBackupType": 0,
+                "restoreControlFile": False,
+                "restoreInstanceLog": False,
+                "duplicate": False,
+                "startLSNNum": "",
+                "checkReadOnly": False,
+                "osID": 2,
+                "specifyControlFile": False,
+                "setDBId": False,
+                "partialRestore": False,
+                "restoreStream": 2,
+                "specifySPFile": False,
+                "restoreSPFile": False,
+                "recover": False,
+                "recoverFrom": 4,
+                "archiveLog": True,
+                "endLSNNum": "",
+                "autoDetectDevice": True,
+                "useEndLog": False,
+                "isDeviceTypeSelected": False,
+                "useStartLog": True,
+                "logTarget": "",
+                "restoreData": False,
+                "restoreFrom": 0,
+                "duplicateToSkipReadOnly": False
+            }
+            if value.get("start_lsn", None):
+                self._oracle_restore_json["useStartLSN"] = True
+                self._oracle_restore_json["startLSNNum"] = value.get("start_lsn")
+            if value.get("end_lsn", None):
+                self._oracle_restore_json["useEndLSN"] = True
+                self._oracle_restore_json["endLSNNum"] = value.get("end_lsn")
+            if value.get("log_dest", None):
+                self._oracle_restore_json["logTarget"] = value.get("log_dest")
+
     def _restore_json(self, **kwargs):
         """Returns the JSON request to pass to the API as per the options selected by the user.
 
@@ -1156,7 +1228,10 @@ class OracleInstance(DatabaseInstance):
             path,
             dest_client_name,
             dest_instance_name,
-            dest_path=None):
+            dest_path=None,
+            restore_oracle_options_type=None,
+            start_lsn=None, end_lsn=None,
+            log_dest=None):
         """Restores the oracle logical dump data/log files specified in the input paths
         list to the same location.
 
@@ -1202,6 +1277,9 @@ class OracleInstance(DatabaseInstance):
             paths=path,
             destination_client=dest_client_name,
             destination_instance=dest_instance_name,
-            destination_path=dest_path)
+            destination_path=dest_path,
+            restore_oracle_options_type=restore_oracle_options_type,
+            start_lsn=start_lsn, end_lsn=end_lsn,
+            log_dest=log_dest)
 
         return self._process_restore_response(request_json)
\ No newline at end of file
