@@ -18,10 +18,12 @@
 
 """Main file for performing plan operations.
 
-Plans and Plan are the classes defined in this file.
+Plans,PlanTypes and Plan are the classes defined in this file.
 
 Plans: Class for representing all the plans in the commcell
 
+PlanTypes : Class for representing plan types
+
 Plan: Class for representing a single plan of the commcell
 
 Plans
@@ -52,6 +54,8 @@ Plans
 
     refresh()                   --  refresh the plans associated with the commcell
 
+    add_data_classification_plan()-  Adds data classification plan to the commcell
+
 Attributes
 ----------
 
@@ -89,6 +93,13 @@ Plan
 
     disable_full_schedule()     --  disables the full schedule of a plan
 
+    share()                     --  shares plan with given user by associating given role
+
+    schedule()                  --  create/delete schedule on DC Plan
+
+    edit_plan()                 --  edit plan options
+
+
 Plan Attributes
 ----------------
     **plan_id**                 --  returns the id of the plan
@@ -116,14 +127,35 @@ Plan Attributes
     **full_operation_window**   --  returns the full operation window set by the plan
 
     **associated_entities**     --  returns all the entities associated with the plan
-"""
 
+    **content_indexing_props**  --  returns the DC plan related properties from the plan
+"""
 from __future__ import unicode_literals
 
+import copy
+from enum import Enum
+
 from past.builtins import basestring
 
 from .exception import SDKException
 
+from .activateapps.constants import TargetApps, PlanConstants
+from functools import reduce
+
+
+class PlanTypes(Enum):
+    """Class Enum to represent different plan types"""
+    Any = 0
+    DLO = 1
+    MSP = 2
+    FS = 3
+    SNAP = 4
+    VSA = 5
+    EXCHANGE = 6
+    DC = 7
+    EDISCOVERY = 8
+    ARCHIVER = 9
+
 
 class Plans(object):
     """Class for representing all the plans in the commcell."""
@@ -486,6 +518,15 @@ class Plans(object):
         request_json['plan']['summary']['rpoInMinutes'] = sla_in_minutes
         request_json['plan']['summary']['description'] = "Created from CvPySDK."
         request_json['plan']['summary']['plan']['planName'] = plan_name
+        request_json['plan']['schedule']['subTasks'][1]['options']['commonOpts'][
+            'automaticSchedulePattern'].update({
+                'minBackupInterval': 0,
+                'maxBackupIntervalMinutes': 0,
+                'minSyncInterval': 0,
+                'minSyncIntervalMinutes': 0
+            })
+        request_json['plan']['schedule']['subTasks'][1]['options']['commonOpts'][
+            'automaticSchedulePattern']['ignoreOpWindowPastMaxInterval'] = True
         del request_json['plan']['schedule']['task']['taskName']
         if not plan_sub_type == 'ExchangeUser':
             request_json['plan']['storage']['copy'][0]['useGlobalPolicy'] = {
@@ -654,6 +695,184 @@ class Plans(object):
         """Refresh the plans associated with the Commcell."""
         self._plans = self._get_plans()
 
+    def add_data_classification_plan(self, plan_name, index_server, target_app=TargetApps.FSO, **kwargs):
+        """Adds data classification plan to the commcell
+
+            Args:
+
+                plan_name           (str)       --  Name of plan
+
+                index_server        (str)       --  Index server name
+
+
+                target_app          (enum)      --  Target app for this plan
+                                                        cvpysdk.activateapps.constants.TargetApps
+
+                **kwargs
+
+                    index_content       (bool)      --  Speifies whether to index content or not to index server
+
+                    content_analyzer    (list)      --  list of Content analyzer cloud name
+
+                    entity_list         (list)      --  list of entities which needs to be extracted
+
+                    classifier_list     (list)      --  list of classifier which needs to be classified
+
+                    enable_ocr          (bool)      --  specifies whether OCR is enabled or not
+
+                    ocr_language        (int)       --  Language to be used when doing OCR
+                                                            Default : English (Value-1)
+
+                     Supported Languages:
+
+                                    ENGLISH = 1,
+                                    HEBREW = 2,
+                                    SPANISH = 3,
+                                    FRENCH = 4,
+                                    ITALIAN = 5,
+                                    DANISH = 6
+
+                    include_docs        (str)       --  Include documents type separated by comma
+
+                    exclude_path        (list)      --  List of paths which needs to be excluded
+
+                    min_doc_size        (int)       --  Minimum document size in MB
+
+                    max_doc_size        (int)       --  Maximum document size in MB
+
+            Returns:
+
+                object  - Plan object
+
+            Raises:
+
+                SDKException:
+
+                        if input is not valid
+
+                        if failed to create plan
+
+                        if failed to find entities/classifier details
+
+        """
+        extraction_policy_list = []
+        if not (isinstance(plan_name, basestring) and
+                isinstance(index_server, basestring)):
+            raise SDKException('Plan', '101')
+        request_json = self._get_plan_template("DataClassification", "MSP")
+        request_json['plan']['summary']['description'] = "DC Plan Created from CvPySDK."
+        request_json['plan']['summary']['plan']['planName'] = plan_name
+        request_json['plan']['options'] = {
+            "enableThreatAnalysis": False,
+            "targetApps": [
+                target_app.value
+            ]
+        }
+        index_server_client_id = self._commcell_object.index_servers.get(index_server).index_server_client_id
+        request_json['plan']['eDiscoveryInfo']['analyticsIndexServer'] = {
+            'clientId': index_server_client_id
+        }
+        if target_app.value == TargetApps.FSO.value:
+            del request_json['plan']['ciPolicy']['detail']['ciPolicy']['filters']
+            request_json['plan']['ciPolicy']['detail']['ciPolicy']['opType'] = PlanConstants.INDEXING_ONLY_METADATA
+        elif target_app.value == TargetApps.SDG.value:
+            if 'content_analyzer' not in kwargs:
+                raise SDKException('Plan', '103')
+            ca_list = []
+            for ca in kwargs.get('content_analyzer', []):
+                ca_cloud_id = self._commcell_object.content_analyzers.get(ca).cloud_id
+                ca_list.append({
+                    'cloudId': ca_cloud_id
+                })
+            request_json['plan']['eDiscoveryInfo']['contentAnalyzerCloud'] = ca_list
+            if 'entity_list' not in kwargs and 'classifier_list' not in kwargs:
+                raise SDKException('Plan', '104')
+            activate_obj = self._commcell_object.activate
+            if 'entity_list' in kwargs or 'classifier_list' in kwargs:
+                entity_mgr_obj = activate_obj.entity_manager()
+                # classifier is also an activate entity with type alone different so append this to entity list itself
+                entity_list = []
+                for entity in kwargs.get('entity_list', []):
+                    entity_list.append(entity)
+                for entity in kwargs.get('classifier_list', []):
+                    entity_list.append(entity)
+                for entity in entity_list:
+                    entity_obj = entity_mgr_obj.get(entity)
+                    extraction_policy_list.append(entity_obj.container_details)
+
+            request_json['plan']['eePolicy']['policyType'] = 3
+            request_json['plan']['eePolicy']['flags'] = 8
+            request_json['plan']['eePolicy']['detail'] = {
+                "eePolicy": {
+                    "copyPrecedence": 0,
+                    "extractionPolicyType": 6,  # container entities
+                    "extractionPolicy": {
+                        "extractionPolicyList": extraction_policy_list
+                    }
+
+                }
+            }
+            if 'index_content' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['opType'] = kwargs.get(
+                    'index_content', PlanConstants.INDEXING_METADATA_AND_CONTENT)
+            if 'enable_ocr' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['enableImageExtraction'] = kwargs.get(
+                    'enable_ocr', False)
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['ocrLanguages'] = [kwargs.get('ocr_language', 1)]
+            if 'include_docs' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters']['includeDocTypes'] = kwargs.get(
+                    'include_docs', PlanConstants.DEFAULT_INCLUDE_DOC_TYPES)
+            if 'min_doc_size' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters']['minDocSize'] = kwargs.get(
+                    'min_doc_size', PlanConstants.DEFAULT_MIN_DOC_SIZE)
+            if 'max_doc_size' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters'][
+                    'maxDocSize'] = kwargs.get('max_doc_size', PlanConstants.DEFAULT_MAX_DOC_SIZE)
+            if 'exclude_path' in kwargs:
+                request_json['plan']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters'][
+                    'excludePaths'] = kwargs.get('exclude_path', PlanConstants.DEFAULT_EXCLUDE_LIST)
+
+        headers = self._commcell_object._headers.copy()
+        headers['LookupNames'] = 'False'
+
+        flag, response = self._cvpysdk_object.make_request(
+            'POST', self._PLANS, request_json, headers=headers
+        )
+
+        if flag:
+            if response.json():
+                response_value = response.json()
+                error_message = None
+                error_code = None
+
+                if 'errors' in response_value:
+                    error_code = response_value['errors'][0]['status']['errorCode']
+                    error_message = response_value['errors'][0]['status']['errorMessage']
+
+                if error_code > 1:
+                    o_str = 'Failed to create new Plan\nError: "{0}"'.format(
+                        error_message
+                    )
+                    raise SDKException('Plan', '102', o_str)
+
+                if 'plan' in response_value:
+                    plan_name = response_value['plan']['summary']['plan']['planName']
+                    # initialize the plans again
+                    self.refresh()
+
+                    return self.get(plan_name)
+                else:
+                    o_str = ('Failed to create new plan due to error code: "{0}"\n'
+                             'Please check the documentation for '
+                             'more details on the error').format(error_code)
+
+                    raise SDKException('Plan', '102', o_str)
+            else:
+                raise SDKException('Response', 102)
+        else:
+            response_string = self._update_response_(response.text)
+            raise SDKException('Response', '101', response_string)
+
 
 class Plan(object):
     """Class for performing operations for a specific Plan."""
@@ -689,6 +908,8 @@ class Plan(object):
 
         self._PLAN = self._services['PLAN'] % (self.plan_id)
         self._ADD_USERS_TO_PLAN = self._services['ADD_USERS_TO_PLAN'] % (self.plan_id)
+        self._API_SECURITY = self._services['SECURITY_ASSOCIATION']
+        self._API_SECURITY_ENTITY = self._services['ENTITY_SECURITY_ASSOCIATION']
 
         self._properties = None
         self._sla_in_minutes = None
@@ -710,6 +931,8 @@ class Plan(object):
         self._parent_plan_name = None
         self._addons = []
         self._associated_entities = {}
+        self._dc_plan_props = {}
+        self._plan_entity_type = 158
         self.refresh()
 
     def __repr__(self):
@@ -741,7 +964,7 @@ class Plan(object):
 
                     if response is not success
         """
-        plan_properties_url = '{0}?propertyLevel=20'.format(self._PLAN)
+        plan_properties_url = '{0}?propertyLevel=30'.format(self._PLAN)
         flag, response = self._cvpysdk_object.make_request('GET', plan_properties_url)
 
         if flag:
@@ -852,6 +1075,25 @@ class Plan(object):
                 if 'parent' in self._plan_properties['summary']:
                     self._parent_plan_name = self._plan_properties['summary']['parent']['planName']
 
+                if 'eePolicy' in self._plan_properties:
+                    extraction_policy = self._plan_properties['eePolicy']
+                    if 'policyEntity' in extraction_policy:
+                        self._dc_plan_props['eePolicyId'] = extraction_policy['policyEntity']['policyId']
+                    if 'detail' in extraction_policy:
+                        self._dc_plan_props['eePolicy'] = extraction_policy['detail']['eePolicy']
+
+                if 'ciPolicy' in self._plan_properties:
+                    ci_policy = self._plan_properties['ciPolicy']
+                    if 'policyEntity' in ci_policy:
+                        self._dc_plan_props['ciPolicyId'] = ci_policy['policyEntity']['policyId']
+                    if 'detail' in ci_policy:
+                        self._dc_plan_props['ciPolicy'] = ci_policy['detail']['ciPolicy']
+
+                if 'options' in self._plan_properties:
+                    plan_options = self._plan_properties['options']
+                    if 'targetApps' in plan_options:
+                        self._dc_plan_props['targetApps'] = plan_options['targetApps']
+
                 if 'securityAssociations' in self._plan_properties:
                     for association in self._plan_properties['securityAssociations']['associations']:
                         temp_key = None
@@ -1612,6 +1854,11 @@ class Plan(object):
         """
         return self._security_associations
 
+    @property
+    def content_indexing_props(self):
+        """returns the DC plan related CI properties from Plan"""
+        return self._dc_plan_props
+
     def refresh(self):
         """Refresh the properties of the Plan."""
         self._properties = self._get_plan_properties()
@@ -1670,3 +1917,254 @@ class Plan(object):
         else:
             response_string = self._update_response_(response.text)
             raise SDKException('Response', '101', response_string)
+
+    def share(self, user_or_group_name, role_name, is_user=True, ops_type=1):
+        """Shares plan with given user or group by associating with given role
+
+                Args:
+
+                    user_or_group_name      (str)       --  User or Group name to which we are sharing
+
+                    role_name               (str)       --  Role name which needs to associated with
+
+                    ops_type                (int)       --  Operation type
+
+                                                            Default : 1 (Add)
+
+                                                            Supported : 1 (Add)
+                                                                        3 (Delete)
+
+                Returns:
+
+                    None
+
+                Raises:
+
+                    SDKException:
+
+                            if input is not valid
+
+                            if failed to do sharing
+
+                            if user/group/role not exists on commcell
+
+                            if failed to get exisitng association details
+
+        """
+        if not isinstance(user_or_group_name, basestring) or not isinstance(role_name, basestring):
+            raise SDKException('Plan', '101')
+        if ops_type not in [1, 3]:
+            raise SDKException('Plan', '102', "Sharing operation type provided is not supported")
+        if is_user:
+            if not self._commcell_object.users.has_user(user_or_group_name):
+                raise SDKException('Plan', '102', "User doesn't exists in the commcell")
+        if not self._commcell_object.roles.has_role(role_name=role_name):
+            raise SDKException('Plan', '102', "Role doesn't exists in the commcell")
+        request_json = copy.deepcopy(PlanConstants.PLAN_SHARE_REQUEST_JSON)
+        association_response = None
+        if ops_type == 1 and len(self.security_associations) > 1:
+            association_request_json = copy.deepcopy(PlanConstants.PLAN_SHARE_REQUEST_JSON)
+            del association_request_json['securityAssociations']
+            association_request_json['entityAssociated']['entity'][0]['entityId'] = int(self._plan_id)
+            flag, response = self._cvpysdk_object.make_request(
+                'GET', self._API_SECURITY_ENTITY %
+                (self._plan_entity_type, int(
+                    self._plan_id)), association_request_json)
+            if flag:
+                if response.json() and 'securityAssociations' in response.json():
+                    association_response = response.json(
+                    )['securityAssociations'][0]['securityAssociations']['associations']
+                else:
+                    raise SDKException('Plan', '102', 'Failed to get existing security associations')
+            else:
+                response_string = self._commcell_object._update_response_(response.text)
+                raise SDKException('Response', '101', response_string)
+
+        external_user = False
+        if '\\' in user_or_group_name:
+            external_user = True
+        if is_user:
+            user_obj = self._commcell_object.users.get(user_or_group_name)
+            user_id = user_obj.user_id
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['userId'] = int(user_id)
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['_type_'] = "13"
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['userName'] = user_or_group_name
+        elif external_user:
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['groupId'] = 0
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['_type_'] = "62"
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0][
+                'externalGroupName'] = user_or_group_name
+        else:
+            grp_obj = self._commcell_object.user_groups.get(user_or_group_name)
+            grp_id = grp_obj.user_group_id
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['userGroupId'] = int(grp_id)
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0]['_type_'] = "15"
+            request_json['securityAssociations']['associations'][0]['userOrGroup'][0][
+                'userGroupName'] = user_or_group_name
+
+        request_json['entityAssociated']['entity'][0]['entityId'] = int(self._plan_id)
+        request_json['securityAssociations']['associationsOperationType'] = ops_type
+        role_obj = self._commcell_object.roles.get(role_name)
+        request_json['securityAssociations']['associations'][0]['properties']['role']['roleId'] = role_obj.role_id
+        request_json['securityAssociations']['associations'][0]['properties']['role']['roleName'] = role_obj.role_name
+
+        # Associate existing associations to the request
+        if ops_type == 1 and len(self.security_associations) > 1:
+            request_json['securityAssociations']['associations'].extend(association_response)
+
+        flag, response = self._cvpysdk_object.make_request(
+            'POST', self._API_SECURITY, request_json
+        )
+        if flag:
+            if response.json() and 'response' in response.json():
+                response_json = response.json()['response'][0]
+                error_code = response_json['errorCode']
+                if error_code != 0:
+                    error_message = response_json['errorString']
+                    raise SDKException(
+                        'Plan',
+                        '102', error_message)
+                self.refresh()
+            else:
+                raise SDKException('Plan', '105')
+        else:
+            response_string = self._commcell_object._update_response_(response.text)
+            raise SDKException('Response', '101', response_string)
+
+    def schedule(self, schedule_name, pattern_json, ops_type=2):
+        """Creates or modifies the schedule associated with plan
+
+                Args:
+
+                    schedule_name       (str)       --  Schedule name
+
+                    pattern_json        (dict)      --  Schedule pattern dict (Refer to Create_schedule_pattern in schedule.py)
+
+                    ops_type            (int)       --  Operation type
+
+                                                            Default : 2 (Add)
+
+                                                            Supported : 2 (Add/Modify)
+
+                Raises:
+
+                      SDKException:
+
+                            if input is not valid
+
+                            if failed to create/modify schedule
+
+                            if plan is not of type Data classification plan
+
+        """
+        if not isinstance(schedule_name, basestring) or not isinstance(pattern_json, dict):
+            raise SDKException('Plan', '101')
+        if self.plan_type not in [PlanTypes.DC.value]:
+            raise SDKException('Plan', '102', "Add/Modify Schedule is supported only for DC Plan via CvpySDK")
+        if ops_type not in [2]:
+            raise SDKException('Plan', '102', "Schedule operation type provided is not supported")
+        request_json = copy.deepcopy(PlanConstants.PLAN_SCHEDULE_REQUEST_JSON[self.plan_type])
+        request_json['summary']['plan']['planId'] = int(self.plan_id)
+        request_json['schedule']['associations'][0]['entityId'] = int(self.plan_id)
+        request_json['schedule']['task']['taskName'] = f"Cvpysdk created Schedule policy for plan - {self.plan_name}"
+        request_json['schedule']['subTasks'][0]['subTask'][
+            'subTaskName'] = schedule_name
+        request_json['schedule']['subTasks'][0]['pattern'] = pattern_json
+        request_json['schedule']['subTasks'][0]['options']['adminOpts']['contentIndexingOption']['operationType'] = ops_type
+        self._update_plan_props(request_json)
+
+    def edit_plan(self, **kwargs):
+        """Edit plan options
+
+                Args:
+
+                    **kwargs for Data Classification Plan
+
+                    index_content       (bool)      --  Speifies whether to index content or not to index server
+
+                    content_analyzer    (list)      --  list of Content analyzer cloud name
+
+                    entity_list         (list)      --  list of entities which needs to be extracted
+
+                    classifier_list     (list)      --  list of classifier which needs to be classified
+
+                    enable_ocr          (bool)      --  specifies whether OCR is enabled or not
+
+                    ocr_language        (int)       --  Language to be used when doing OCR
+                                                            Default : English (Value-1)
+
+                     Supported Languages:
+
+                                    ENGLISH = 1,
+                                    HEBREW = 2,
+                                    SPANISH = 3,
+                                    FRENCH = 4,
+                                    ITALIAN = 5,
+                                    DANISH = 6
+
+                    include_docs        (str)       --  Include documents type separated by comma
+
+                    exclude_path        (list)      --  List of paths which needs to be excluded
+
+                    min_doc_size        (int)       --  Minimum document size in MB
+
+                    max_doc_size        (int)       --  Maximum document size in MB
+        """
+        if self.plan_type != PlanTypes.DC.value:
+            raise SDKException('Plan', '102', "Function Not supported for this plan type")
+        extraction_policy_list = []
+        request_json = None
+        if self.plan_type == PlanTypes.DC.value:
+            request_json = copy.deepcopy(PlanConstants.PLAN_UPDATE_REQUEST_JSON[self.plan_type])
+            request_json['summary']['plan']['planId'] = int(self.plan_id)
+            if TargetApps.SDG.value in self.content_indexing_props['targetApps']:
+                request_json['eePolicyInfo']['eePolicy']['detail']['eePolicy'] = self.content_indexing_props['eePolicy']
+                request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy'] = self.content_indexing_props['ciPolicy']
+                activate_obj = self._commcell_object.activate
+                if 'content_analyzer' in kwargs:
+                    ca_list = []
+                    for ca in kwargs.get('content_analyzer', []):
+                        ca_cloud_id = self._commcell_object.content_analyzers.get(ca).cloud_id
+                        ca_list.append({
+                            'cloudId': ca_cloud_id
+                        })
+                    request_json['eDiscoveryInfo'] = {
+                        'contentAnalyzerCloud': ca_list}
+                if 'entity_list' in kwargs or 'classifier_list' in kwargs:
+                    entity_mgr_obj = activate_obj.entity_manager()
+                    # classifier is also an activate entity with type alone different so
+                    # append this to entity list itself
+                    entity_list = []
+                    for entity in kwargs.get('entity_list', []):
+                        entity_list.append(entity)
+                    for entity in kwargs.get('classifier_list', []):
+                        entity_list.append(entity)
+                    for entity in entity_list:
+                        entity_obj = entity_mgr_obj.get(entity)
+                        extraction_policy_list.append(entity_obj.container_details)
+                    request_json['eePolicyInfo']['eePolicy']['detail']['eePolicy']['extractionPolicy']['extractionPolicyList'] = extraction_policy_list
+
+                if 'enable_ocr' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['enableImageExtraction'] = kwargs.get(
+                        'enable_ocr', False)
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['ocrLanguages'] = [
+                        kwargs.get('ocr_language', 1)]
+                if 'include_docs' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters']['includeDocTypes'] = kwargs.get(
+                        'include_docs', PlanConstants.DEFAULT_INCLUDE_DOC_TYPES)
+                if 'min_doc_size' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters']['minDocSize'] = kwargs.get(
+                        'min_doc_size', PlanConstants.DEFAULT_MIN_DOC_SIZE)
+                if 'max_doc_size' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters'][
+                        'maxDocSize'] = kwargs.get('max_doc_size', PlanConstants.DEFAULT_MAX_DOC_SIZE)
+                if 'exclude_path' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['filters']['fileFilters'][
+                        'excludePaths'] = kwargs.get('exclude_path', PlanConstants.DEFAULT_EXCLUDE_LIST)
+                if 'index_content' in kwargs:
+                    request_json['ciPolicyInfo']['ciPolicy']['detail']['ciPolicy']['opType'] = kwargs.get(
+                        'index_content', PlanConstants.INDEXING_METADATA_AND_CONTENT)
+            elif TargetApps.FSO.value in self.content_indexing_props['targetApps']:
+                # currently we dont have any thing to update in DC plan for FSO app so throw exception
+                raise SDKException('Plan', '102', 'No attributes to Edit for DC Plan with TargetApps as : FSO')
+        self._update_plan_props(request_json)
