@@ -79,6 +79,8 @@ User
     associated_usergroups()             --  returns the usergroups associated with
                                             this user
 
+    associated_external_usergroups()    -- returns the external usergroups associated with this user
+
     add_usergroups()                    --  associates the usergroups with this user
 
     remove_usergroups()                 --  disassociated the usergroups with this user
@@ -102,6 +104,8 @@ User
 
     age_password_days()                 --  returns age password days for user
 
+    user_company_name()                 -- returns company name if user is a company user else returns empty str
+
 """
 
 from base64 import b64encode
@@ -565,6 +569,7 @@ class User(object):
         self._user_status = None
         self._email = None
         self._description = None
+        self._associated_external_usergroups = None
         self._associated_usergroups = None
         self._properties = None
         self._tfa_status = None
@@ -612,6 +617,9 @@ class User(object):
 
                 if 'associatedUserGroups' in self._properties:
                     self._associated_usergroups = self._properties['associatedUserGroups']
+
+                if 'associatedExternalUserGroups' in self._properties:
+                    self._associated_external_usergroups = self._properties['associatedExternalUserGroups']
             else:
                 raise SDKException('Response', '102')
         else:
@@ -759,6 +767,15 @@ class User(object):
                 usergroups.append(usergroup['userGroupName'])
         return usergroups
 
+    @property
+    def associated_external_usergroups(self):
+        """Returns the list of associated external usergroups"""
+        usergroups = []
+        if self._associated_external_usergroups is not None:
+            for usergroup in self._associated_external_usergroups:
+                usergroups.append(usergroup['externalGroupName'])
+        return usergroups
+
     @property
     def user_security_associations(self):
         """Returns security associations from properties of the User."""
@@ -809,6 +826,14 @@ class User(object):
         """
         return self._properties.get('agePasswordDays')
 
+    @property
+    def user_company_name(self):
+        """
+        returns user associated company name
+        """
+
+        return self._properties.get('userEntity', {}).get('entityInfo', {}).get('companyName')
+
     @age_password_days.setter
     def age_password_days(self, days):
         """
