@@ -97,6 +97,14 @@ UserGroup:
 
     associations()                  --  Returns security associations present on the usergroup
 
+    is_tfa_enabled()                --  Returns status of tfa
+
+    enable_tfa()                    --  Enables tfa for this user group
+
+    disable_tfa()                   --  Disables tfa for this user group
+
+    update_navigation_preferences   --  Updates user group navigation preferences
+
 """
 
 from __future__ import absolute_import
@@ -640,6 +648,41 @@ class UserGroup(object):
         """Returns security associations present on th usergroup"""
         return self._security_associations
 
+    @property
+    def is_tfa_enabled(self):
+        """Returns two factor authentication status (True/False)"""
+        return self._properties.get('enableTwoFactorAuthentication') == 1
+
+    def enable_tfa(self):
+        """
+        enables two factor authentication on this group
+
+            Note: tfa will not get enabled for this user group if global tfa is disabled
+
+        Returns:
+             None
+        """
+        request_json = {
+            "groups": [{
+                "enableTwoFactorAuthentication": 1
+            }]
+        }
+        self._update_usergroup_props(request_json)
+
+    def disable_tfa(self):
+        """
+        disables two factor authentication for this group
+
+        Returns:
+            None
+        """
+        request_json = {
+            "groups": [{
+                "enableTwoFactorAuthentication": 0
+            }]
+        }
+        self._update_usergroup_props(request_json)
+
     def update_security_associations(self, entity_dictionary, request_type):
         """handles three way associations (role-usergroup-entities)
 
@@ -755,6 +798,36 @@ class UserGroup(object):
         self._send_request(request_type=request_type, users_blob=userlist_json,
                            external_group_blob=usergroup_json, local_group_blob=local_groups_json)
 
+    def update_navigation_preferences(self, include_navigation_list):
+        """Updates the user group's include navigation preferences with the the list provided
+
+            Args:
+                include_navigation_list   (list)    --  list of navigation items to be seen in command center
+
+            Raises:
+                SDKException:
+
+                    if failed update user properties
+
+        """
+        request_json = {
+            'groups': [
+                {
+                    'additionalSettings': [
+                        {
+                            'deleted': 0,
+                            'relativepath': 'CommServDB.AdminConsole',
+                            'keyName': 'includeNavItems',
+                            'type': 'MULTISTRING',
+                            'value': ','.join(include_navigation_list),
+                            'enabled': 1
+                        }
+                    ]
+                }
+            ]
+        }
+        self._update_usergroup_props(request_json)
+
     def _send_request(self, request_type, association_blob=None, users_blob=None,
                       external_group_blob=None, local_group_blob=None):
         """forms complete json request for user groups
