@@ -212,7 +212,9 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
                                      add_to_failover=False,
                                      network=None,
                                      restored_vm_name=None,
-                                     restore_option=None):
+                                     restore_option=None,
+                                     snap_proxy=None,
+                                     media_agent=None):
         """Restores the FULL Virtual machine specified  in the input  list to the client,
             at the specified destination location.
 
@@ -239,6 +241,10 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
                 restore_option      (dict)     --  complete dictionary with all advanced optio
                     default: {}
 
+                snap_proxy          (strig)     -- Snap proxy to be used for restore
+
+                media_agent          (string)    -- Media Agent to be used for Browse
+
         value:
             preserve_level           (int)    -  set the preserve level in restore
             unconditional_overwrite  (bool)  - unconditionally overwrite the disk
@@ -297,9 +303,6 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
         if vm_to_restore and not isinstance(vm_to_restore, basestring):
             raise SDKException('Subclient', '101')
 
-        if not restored_vm_name and isinstance(vm_to_restore, basestring):
-            restored_vm_name = "Delete" + vm_to_restore
-
         if copy_precedence:
             restore_option["copy_precedence_applicable"] = True
 
@@ -335,7 +338,9 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
             add_to_failover=add_to_failover,
             datastore=destination_path,
             in_place=False,
-            network=network
+            destination_network=network,
+            snap_proxy=snap_proxy,
+            media_agent=media_agent
         )
 
         request_json = self._prepare_fullvm_restore_json(restore_option)
@@ -390,6 +395,9 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
         if copy_precedence:
             restore_option["copy_precedence_applicable"] = True
 
+        if vm_to_restore and isinstance(vm_to_restore, basestring):
+            vm_to_restore = [vm_to_restore]
+
         # set attr for all the option in restore xml from user inputs
         self._set_restore_inputs(
             restore_option,
@@ -548,7 +556,8 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
             azure_client,
             vm_to_restore=None,
             resource_group=None,
-            storage_account=True,
+            storage_account=None,
+            datacenter=None,
             proxy_client=None,
             overwrite=True,
             power_on=True,
@@ -556,7 +565,12 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
             public_ip=False,
             restore_as_managed=False,
             copy_precedence=0,
-            restore_option=None):
+            disk_type=None,
+            restore_option=None,
+            networkDisplayName=None,
+            networkrsg=None,
+            destsubid=None,
+            subnetId=None):
         """
                 This converts the Hyperv VM to AzureRM
                 Args:
@@ -595,6 +609,16 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
 
                         proxy_client      (basestring):   destination proxy client
 
+                        networkDisplayName(basestring):   destination network display name
+
+                        networkrsg        (basestring):   destination network display name's security group
+
+                        destsubid         (basestring):   destination subscription id
+
+                        subnetId          (basestring):   destination subet id
+
+
+
                     Returns:
                         object - instance of the Job class for this restore job
 
@@ -612,6 +636,11 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
         if restore_option is None:
             restore_option = {}
 
+        if vm_to_restore and not isinstance(vm_to_restore, basestring):
+            raise SDKException('Subclient', '101')
+
+        if not isinstance(vm_to_restore, list):
+            vm_to_restore = [vm_to_restore]
         # check mandatory input parameters are correct
         if not isinstance(azure_client, basestring):
             raise SDKException('Subclient', '101')
@@ -627,6 +656,7 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
             vcenter_client=azure_client,
             datastore=storage_account,
             esx_host=resource_group,
+            datacenter=datacenter,
             unconditional_overwrite=overwrite,
             client_name=proxy_client,
             power_on=power_on,
@@ -637,7 +667,11 @@ class HyperVVirtualServerSubclient(VirtualServerSubclient):
             instanceSize=instance_size,
             volume_level_restore=1,
             destination_instance=instance.instance_name,
-            backupset_client_name=instance._agent_object._client_object.client_name
+            backupset_client_name=instance._agent_object._client_object.client_name,
+            networkDisplayName=networkDisplayName,
+            networkrsg=networkrsg,
+            destsubid=destsubid,
+            subnetId=subnetId
         )
 
         request_json = self._prepare_fullvm_restore_json(restore_option)
